#include "basicscorecard.h"
#include "ui_basicscorecard.h"
#include "datahandling.h"
#include "courses.h"
#include <QtDebug>

BasicScorecard::BasicScorecard(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::BasicScorecard)
{
    ui->setupUi(this);
    currentCourse = 1;
    loadPlayers();
    loadCourses();
    hideNotNeededFields();
    drawPlayers();
    displayCourseData();
    calculateHcpsPerCourse();
}

void BasicScorecard::loadPlayers()
{
    datahandling *CAPData = datahandling::instance();

    players << CAPData->selectedPlayers;
    qDebug() << players;

    for(int i = 0; i < players.count(); i++)
    {
        for(int j = 0; j < 19; j++)
        {
            scores[i][j] = 0;
            hcpPerCourse[i][j] = 0;
        }
    }

    for(int i = 0; i < players.count(); i++)
    {
        hcp[i] = CAPData->selectedPlayersHandicap[i].toInt();
        qDebug() << hcp[i];
    }

    for(int y = 0; y < 19; y++)
    {
        hcpOrder[y] = 0;
    }



}

void BasicScorecard::drawPlayers()
{
    if(players.count() >= 1 )
    {
        ui->label_leaderboardPlayer1->setText(players[0]);
        ui->label_player1->setText(players[0]);
    }
    if(players.count() >= 2)
    {
        ui->label_leaderboardPlayer2->setText(players[1]);
        ui->label_player2->setText(players[1]);
    }
    if(players.count() >= 3)
    {
        ui->label_leaderboardPlayer3->setText(players[2]);
        ui->label_player3->setText(players[2]);
    }
    if(players.count() >= 4)
    {
        ui->label_leaderboardPlayer4->setText(players[3]);
        ui->label_player4->setText(players[3]);
    }
}

void BasicScorecard::saveShots()
{
    if(players.count() >= 1 )
        scores[0][currentCourse] = ui->label_player1_score->text().toInt();
    if(players.count() >= 2 )
        scores[1][currentCourse] = ui->label_player2_score->text().toInt();
    if(players.count() >= 3 )
        scores[2][currentCourse] = ui->label_player3_score->text().toInt();
    if(players.count() >= 4 )
        scores[3][currentCourse] = ui->label_player4_score->text().toInt();
}

void BasicScorecard::loadShots()
{
    if(players.count() >= 1 )
        ui->label_player1_score->setText(QString::number(scores[0][currentCourse]));
    if(players.count() >= 2 )
        ui->label_player2_score->setText(QString::number(scores[1][currentCourse]));
    if(players.count() >= 3 )
        ui->label_player3_score->setText(QString::number(scores[2][currentCourse]));
    if(players.count() >= 4 )
        ui->label_player4_score->setText(QString::number(scores[3][currentCourse]));
}

void BasicScorecard::loadCourses()
{
    datahandling *CAPData = datahandling::instance();

    const QList<holeData>& holeData_2 = CAPData->getHoleData();
    const QList<whiteTee>& whiteTee_2 = CAPData->getWhiteTee();
    const QList<yellowTee>& yellowTee_2 = CAPData->getYellowTee();
    const QList<blueTee>& blueTee_2 = CAPData->getBlueTee();
    const QList<redTee>& redTee_2 = CAPData->getRedTee();

    courseDataName << "";
    courseDataPar << "";
    courseDataHcp << "";
    courseDataWhite << "";
    courseDataYellow << "";
    courseDataRed << "";
    courseDataBlue << "";

    foreach(holeData hD, holeData_2)
    {
        courseDataName.push_back(hD.m_id);
        courseDataPar.push_back(hD.m_par);
        courseDataHcp.push_back(hD.m_hcp);
    }

    foreach(whiteTee wT, whiteTee_2)
    {
        courseDataWhite.push_back(wT.m_length);
    }

    foreach(yellowTee yT, yellowTee_2)
    {
        courseDataYellow.push_back(yT.m_length);
    }

    foreach(blueTee bT, blueTee_2)
    {
        courseDataBlue.push_back(bT.m_length);
    }

    foreach(redTee rT, redTee_2)
    {
        courseDataRed.push_back(rT.m_length);
    }
}

void BasicScorecard::displayCourseData()
{
    ui->label_course->setText(courseDataName[currentCourse]);
    ui->label_par->setText(courseDataPar[currentCourse]);
    ui->label_hcp->setText(courseDataHcp[currentCourse]);
    ui->label_white->setText(courseDataWhite[currentCourse]);
    ui->label_yellow->setText(courseDataYellow[currentCourse]);
    ui->label_red->setText(courseDataRed[currentCourse]);
    ui->label_blue->setText(courseDataBlue[currentCourse]);

    for(int i = 0; i < players.count(); i++)
    {
        qDebug() << hcpPerCourse[i][currentCourse];
    }
    qDebug() << "----------";

}

void BasicScorecard::updateLeaderboard()
{
    int sp[4];
    int hcpsp[4];
    int order[4];
    int flag[4];
    int flag2[4];
    int set = 0;

    for(int i = 0; i < 4; i++)
    {
        sp[i] = 0;
        hcpsp[i] = 0;
        order[i] = 0;
        flag[i] = 0;
        flag2[i] = 0;
    }

    for(int i = 0; i < players.count(); i++)
    {
        for(int j = 1; j < 19; j++)
        {
            if(scores[i][j] != 0)
            {
                sp[i] = sp[i] + (scores[i][j] - courseDataPar[j].toInt());
                hcpsp[i] = hcpsp[i] + (scores[i][j] - hcpPerCourse[i][j] - courseDataPar[j].toInt());
            }
        }
    }

    QList<int> list;
    for(int i = 0; i < players.count(); i++)
    {
        list.append(sp[i]);
    }

    qSort(list);

    for(int i = 0; i < players.count(); i++)
    {
        order[i] = (int)list.takeFirst();
    }

    for(int i = 0; i < players.count(); i++)
    {
        for(int j = 0; j < players.count(); j++)
        {
            if((order[i] == sp[j]))
            {
                if(flag[0] != 1 && set == 0 && flag2[j] == 0)
                {
                    flag[0] = 1;
                    set = 1;

                    if(j == 0)
                        flag2[0] = 1;
                    else if(j == 1 && players.count() >= 2)
                        flag2[1] = 1;
                    else if(j == 2 && players.count() >= 3)
                        flag2[2] = 1;
                    else if(j == 3 && players.count() >= 4)
                        flag2[3] = 1;


                    ui->label_leaderboardPlayer1->setText(players[j]);

                    if(sp[j] > 0)
                        ui->label_leaderboardPlayer1_2->setText("+"+QString::number(sp[j]));
                    else if (sp[j] == 0)
                        ui->label_leaderboardPlayer1_2->setText("PAR");
                    else
                        ui->label_leaderboardPlayer1_2->setText(QString::number(sp[j]));

                    if(hcpsp[j] > 0)
                        ui->label_leaderboardPlayer1_3->setText("+"+QString::number(hcpsp[j]));
                    else if (hcpsp[j] == 0)
                        ui->label_leaderboardPlayer1_3->setText("PAR");
                    else
                        ui->label_leaderboardPlayer1_3->setText(QString::number(hcpsp[j]));
                }
                else if(flag[1] != 1 && set == 0 && flag2[j] == 0 && players.count() >= 2)
                {
                    flag[1] = 1;
                    set = 1;

                    if(j == 0)
                        flag2[0] = 1;
                    else if(j == 1 && players.count() >= 2)
                        flag2[1] = 1;
                    else if(j == 2 && players.count() >= 3)
                        flag2[2] = 1;
                    else if(j == 3 && players.count() >= 4)
                        flag2[3] = 1;

                    ui->label_leaderboardPlayer2->setText(players[j]);

                    if(sp[j] > 0)
                        ui->label_leaderboardPlayer2_2->setText("+"+QString::number(sp[j]));
                    else if (sp[j] == 0)
                        ui->label_leaderboardPlayer2_2->setText("PAR");
                    else
                        ui->label_leaderboardPlayer2_2->setText(QString::number(sp[j]));

                    if(hcpsp[j] > 0)
                        ui->label_leaderboardPlayer2_3->setText("+"+QString::number(hcpsp[j]));
                    else if (hcpsp[j] == 0)
                        ui->label_leaderboardPlayer2_3->setText("PAR");
                    else
                        ui->label_leaderboardPlayer2_3->setText(QString::number(hcpsp[j]));
                }
                else if(flag[2] != 1 && set == 0 && flag2[j] == 0 && players.count() >= 3)
                {
                    flag[2] = 1;
                    set = 1;

                    if(j == 0)
                        flag2[0] = 1;
                    else if(j == 1 && players.count() >= 2)
                        flag2[1] = 1;
                    else if(j == 2 && players.count() >= 3)
                        flag2[2] = 1;
                    else if(j == 3 && players.count() >= 4)
                        flag2[3] = 1;

                    ui->label_leaderboardPlayer3->setText(players[j]);

                    if(sp[j] > 0)
                        ui->label_leaderboardPlayer3_2->setText("+"+QString::number(sp[j]));
                    else if (sp[j] == 0)
                        ui->label_leaderboardPlayer3_2->setText("PAR");
                    else
                        ui->label_leaderboardPlayer3_2->setText(QString::number(sp[j]));

                    if(hcpsp[j] > 0)
                        ui->label_leaderboardPlayer3_3->setText("+"+QString::number(hcpsp[j]));
                    else if (hcpsp[j] == 0)
                        ui->label_leaderboardPlayer3_3->setText("PAR");
                    else
                        ui->label_leaderboardPlayer3_3->setText(QString::number(hcpsp[j]));
                }
                else if(flag[3] != 1 && set == 0 && flag2[j] == 0 && players.count() >= 4)
                {
                    flag[3] = 1;
                    set = 1;

                    if(j == 0)
                        flag2[0] = 1;
                    else if(j == 1 && players.count() >= 2)
                        flag2[1] = 1;
                    else if(j == 2 && players.count() >= 3)
                        flag2[2] = 1;
                    else if(j == 3 && players.count() >= 4)
                        flag2[3] = 1;

                    ui->label_leaderboardPlayer4->setText(players[j]);

                    if(sp[j] > 0)
                        ui->label_leaderboardPlayer4_2->setText("+"+QString::number(sp[j]));
                    else if (sp[j] == 0)
                        ui->label_leaderboardPlayer4_2->setText("PAR");
                    else
                        ui->label_leaderboardPlayer4_2->setText(QString::number(sp[j]));

                    if(hcpsp[j] > 0)
                        ui->label_leaderboardPlayer4_3->setText("+"+QString::number(hcpsp[j]));
                    else if (hcpsp[j] == 0)
                        ui->label_leaderboardPlayer4_3->setText("PAR");
                    else
                        ui->label_leaderboardPlayer4_3->setText(QString::number(hcpsp[j]));
                }
                set = 0;
            }    
        }
    }
}

void BasicScorecard::calculateHcpsPerCourse()
{
    int temp = 1;
    bool found = false;

    for(int i = 1; i < 19; i++)
    {
        for(int j = 1; j < 19; j++)
        {
            if(courseDataHcp[j].toInt() == temp && found == false)
            {
                hcpOrder[i] = j;
                temp++;
                found = true;
            }

        }
        found = false;
    }
    int k=1;
    int temp2;
    for(int j = 0; j < players.count(); j++)
    {
        for(int i = 0; i < hcp[j]; i++)
        {
            if(k == 19)
                k = 1;
            temp2 = hcpOrder[k];
            hcpPerCourse[j][temp2]++;
            k++;
        }
        k=1;
    }
}

void BasicScorecard::on_player1_up_clicked()
{
    int temp;
    temp = ui->label_player1_score->text().toInt();
    if(temp < 99)
        temp++;
    ui->label_player1_score->setText(QString::number(temp));
}

void BasicScorecard::on_player1_down_clicked()
{
    int temp;
    temp = ui->label_player1_score->text().toInt();
    if(temp > 0)
        temp--;
    ui->label_player1_score->setText(QString::number(temp));
}

void BasicScorecard::on_player2_up_clicked()
{
    int temp;
    temp = ui->label_player2_score->text().toInt();
    if(temp < 99)
        temp++;
    ui->label_player2_score->setText(QString::number(temp));
}

void BasicScorecard::on_player2_down_clicked()
{
    int temp;
    temp = ui->label_player2_score->text().toInt();
    if(temp > 0)
        temp--;
    ui->label_player2_score->setText(QString::number(temp));
}

void BasicScorecard::on_player3_up_clicked()
{
    int temp;
    temp = ui->label_player3_score->text().toInt();
    if(temp < 99)
        temp++;
    ui->label_player3_score->setText(QString::number(temp));
}

void BasicScorecard::on_player3_down_clicked()
{
    int temp;
    temp = ui->label_player3_score->text().toInt();
    if(temp > 0)
        temp--;
    ui->label_player3_score->setText(QString::number(temp));
}

void BasicScorecard::on_player4_up_clicked()
{
    int temp;
    temp = ui->label_player4_score->text().toInt();
    if(temp < 99)
        temp++;
    ui->label_player4_score->setText(QString::number(temp));
}

void BasicScorecard::on_player4_down_clicked()
{
    int temp;
    temp = ui->label_player4_score->text().toInt();
    if(temp > 0)
        temp--;
    ui->label_player4_score->setText(QString::number(temp));
}

void BasicScorecard::on_pushButton_nextCourse_clicked()
{
    saveShots();

    if(currentCourse < 18)
        currentCourse++;
    else
        currentCourse = 1;

    loadShots();
    displayCourseData();
    updateLeaderboard();

}


void BasicScorecard::on_pushButton_prevCourse_clicked()
{
    saveShots();

    if(currentCourse > 1)
        currentCourse--;
    else
        currentCourse = 18;

    loadShots();
    displayCourseData();
    updateLeaderboard();
}

void BasicScorecard::on_courseMap_clicked()
{

}

void BasicScorecard::hideNotNeededFields()
{
    if(players.count() == 1)
    {
        ui->label_player2->setText("");
        ui->label_player2_score->setText("");;
        ui->player2_down->setHidden(true);
        ui->player2_up->setHidden(true);
        ui->label_leaderboardPlayer2->setHidden(true);
        ui->label_leaderboardPlayer2_2->setHidden(true);
        ui->label_leaderboardPlayer2_3->setHidden(true);

        ui->label_player3->setText("");
        ui->label_player3_score->setText("");;
        ui->player3_down->setHidden(true);
        ui->player3_up->setHidden(true);
        ui->label_leaderboardPlayer3->setHidden(true);
        ui->label_leaderboardPlayer3_2->setHidden(true);
        ui->label_leaderboardPlayer3_3->setHidden(true);

        ui->label_player4->setText("");
        ui->label_player4_score->setText("");;
        ui->player4_down->setHidden(true);
        ui->player4_up->setHidden(true);
        ui->label_leaderboardPlayer4->setHidden(true);
        ui->label_leaderboardPlayer4_2->setHidden(true);
        ui->label_leaderboardPlayer4_3->setHidden(true);
    }
    else if(players.count() == 2)
    {
        ui->label_player3->setText("");
        ui->label_player3_score->setText("");;
        ui->player3_down->setHidden(true);
        ui->player3_up->setHidden(true);
        ui->label_leaderboardPlayer3->setHidden(true);
        ui->label_leaderboardPlayer3_2->setHidden(true);
        ui->label_leaderboardPlayer3_3->setHidden(true);

        ui->label_player4->setText("");
        ui->label_player4_score->setText("");;
        ui->player4_down->setHidden(true);
        ui->player4_up->setHidden(true);
        ui->label_leaderboardPlayer4->setHidden(true);
        ui->label_leaderboardPlayer4_2->setHidden(true);
        ui->label_leaderboardPlayer4_3->setHidden(true);
    }
    else if(players.count() == 3)
    {
        ui->label_player4->setText("");
        ui->label_player4_score->setText("");;
        ui->player4_down->setHidden(true);
        ui->player4_up->setHidden(true);
        ui->label_leaderboardPlayer4->setHidden(true);
        ui->label_leaderboardPlayer4_2->setHidden(true);
        ui->label_leaderboardPlayer4_3->setHidden(true);
    }
}
