#include "datahandling.h"
#include "newround.h"
#include "xmlparser.h"
#include "basicscorecard.h"
#include <QtDebug>

datahandling::datahandling()
{

}

const QList<player>& datahandling::getPlayers()
{
    return m_players;
}

void datahandling::addPlayer(QString name,QString hcp,QString gender)
{
    m_players.push_back(player(name,hcp,gender));
}

const QList<course>& datahandling::getCourses()
{
    return m_courses;
}

void datahandling::addCourses(QString name, QString file)
{
    m_courses.push_back(course(name, file));
}

const QList<courseData>& datahandling::getCourseData()
{
    return m_courseData;
}

void datahandling::addCourseData(QString name, QString par, double latitude, double longitude, QString country, QString city)
{
    m_courseData.push_back(courseData(name, par, latitude, longitude, country, city));
}

const QList<courseCrMale>& datahandling::getCourseCrMale()
{
    return m_courseCrMale;
}

void datahandling::addCourseCrMale(double white, double yellow, double blue, double red)
{
    m_courseCrMale.push_back(courseCrMale(white, yellow, blue, red));
}

const QList<courseCrFemale>& datahandling::getCourseCrFemale()
{
    return m_courseCrFemale;
}

void datahandling::addCourseCrFemale(double yellow, double blue, double red)
{
    m_courseCrFemale.push_back(courseCrFemale(yellow, blue, red));
}

const QList<courseSlopeMale>& datahandling::getCourseSlopeMale()
{
    return m_courseSlopeMale;
}

void datahandling::addCourseSlopeMale(double white, double yellow, double blue, double red)
{
    m_courseSlopeMale.push_back(courseSlopeMale(white, yellow, blue, red));
}

const QList<courseSlopeFemale>& datahandling::getCourseSlopeFemale()
{
    return m_courseSlopeFemale;
}

void datahandling::addCourseSlopeFemale(double yellow, double blue, double red)
{
    m_courseSlopeFemale.push_back(courseSlopeFemale(yellow, blue, red));
}

const QList<holeData>& datahandling::getHoleData()
{
    return m_holeData;
}

void datahandling::addHoleData(QString id, QString hcp, QString par, QString map_uri)
{
    m_holeData.push_back(holeData(id, hcp, par, map_uri));
}

const QList<whiteTee>& datahandling::getWhiteTee()
{
    return m_whiteTee;
}

void datahandling::addWhiteTee(QString length, double latitude, double longitude)
{
    m_whiteTee.push_back(whiteTee(length, latitude, longitude));
}

const QList<yellowTee>& datahandling::getYellowTee()
{
    return m_yellowTee;
}

void datahandling::addYellowTee(QString length, double latitude, double longitude)
{
    m_yellowTee.push_back(yellowTee(length, latitude, longitude));
}

const QList<blueTee>& datahandling::getBlueTee()
{
    return m_blueTee;
}

void datahandling::addBlueTee(QString length, double latitude, double longitude)
{
    m_blueTee.push_back(blueTee(length, latitude, longitude));
}

const QList<redTee>& datahandling::getRedTee()
{
    return m_redTee;
}

void datahandling::addRedTee(QString length, double latitude, double longitude)
{
    m_redTee.push_back(redTee(length, latitude, longitude));
}

const QList<greenInfo>& datahandling::getGreenInfo()
{
    return m_greenInfo;
}

void datahandling::addGreenInfo(double latitude, double longitude)
{
    m_greenInfo.push_back(greenInfo(latitude, longitude));
}

void datahandling::clearData()
{
    m_players.clear();
    m_courses.clear();
}

datahandling* datahandling::instance()
{
    if (m_instance==0)
        m_instance = new datahandling();

    return (m_instance);
}

void datahandling::calculateHandicaps()
{
    double cr[4];
    double fcr[3];
    double slope[4];
    double fslope[3];
    int par=0;
    QStringList temp;

    for(int i = 0; i < 4; i++)
    {
        cr[i] = 0;
        slope[i] = 0;
    }

    for(int i = 0; i < 3; i++)
    {
        fcr[i] = 0;
        fslope[i] = 0;
    }


    this->selectedPlayersHandicap.clear();

    foreach(courseData cD,this->m_courseData)
    {
        temp.push_back(cD.m_par);
        par = temp[0].toInt();
    }

    temp.clear();

    foreach(courseCrMale crM, this->m_courseCrMale)
    {
        cr[0] = (double)crM.m_white;
        cr[1] = (double)crM.m_yellow;
        cr[2] = (double)crM.m_blue;
        cr[3] = (double)crM.m_red;
    }

    temp.clear();

    foreach(courseSlopeMale sM, this->m_courseSlopeMale)
    {
        slope[0] = sM.m_white;
        slope[1] = sM.m_yellow;
        slope[2] = sM.m_blue;
        slope[3] = sM.m_red;
    }

    temp.clear();

    foreach(courseCrFemale crF, this->m_courseCrFemale)
    {
        fcr[0] = crF.m_yellow;
        fcr[1] = crF.m_blue;
        fcr[2] = crF.m_red;
    }

    temp.clear();

    foreach(courseSlopeFemale sF, this->m_courseSlopeFemale)
    {
        fslope[0] = sF.m_yellow;
        fslope[1] = sF.m_blue;
        fslope[2] = sF.m_red;
    }

    for(int i = 0; i < this->selectedPlayers.count(); i++)
    {
        int handicap;
        if(QString::compare(this->selectedPlayersTee[i], "White", Qt::CaseInsensitive) == 0 &&
           QString::compare(this->selectedPlayersGender[i], "male", Qt::CaseInsensitive) == 0)
        {

            handicap = this->selectedPlayersHcp[i].toDouble() * (double)(slope[0] / 113) + (double)(cr[0] - par) + 0.5;
            selectedPlayersHandicap << QString::number(handicap);
            qDebug() << "Male White: " << handicap;
            qDebug() << "Slope: " << slope[0] << " CR: " << cr[0];

        }
        else if(QString::compare(this->selectedPlayersTee[i], "Yellow", Qt::CaseInsensitive) == 0 &&
                QString::compare(this->selectedPlayersGender[i], "male", Qt::CaseInsensitive) == 0)
        {
            handicap = this->selectedPlayersHcp[i].toDouble() * (double)(slope[1] / 113) + (double)(cr[1] - par) + 0.5;
            selectedPlayersHandicap << QString::number(handicap);
            qDebug() << "Male Yellow: " << handicap;

        }
        else if(QString::compare(this->selectedPlayersTee[i], "Blue", Qt::CaseInsensitive) == 0 &&
                QString::compare(this->selectedPlayersGender[i], "male", Qt::CaseInsensitive) == 0)
        {
            handicap = this->selectedPlayersHcp[i].toDouble() * (double)(slope[2] / 113) + (double)(cr[2] - par) + 0.5;
            selectedPlayersHandicap << QString::number(handicap);
            qDebug() << "Male Blue: " << handicap;

        }
        else if(QString::compare(this->selectedPlayersTee[i], "Red", Qt::CaseInsensitive) == 0 &&
                QString::compare(this->selectedPlayersGender[i], "male", Qt::CaseInsensitive) == 0)
        {
            handicap = this->selectedPlayersHcp[i].toDouble() * (double)(slope[3] / 113) + (double)(cr[3] - par) + 0.5;
            selectedPlayersHandicap << QString::number(handicap);
            qDebug() << "Male Red: " << handicap;

        }

        if(QString::compare(this->selectedPlayersTee[i], "White", Qt::CaseInsensitive) == 0 &&
           QString::compare(this->selectedPlayersGender[i], "female", Qt::CaseInsensitive) == 0)
        {

            handicap = this->selectedPlayersHcp[i].toDouble() * (double)(fslope[0] / 113) + (double)(fcr[0] - par) + 0.5;
            selectedPlayersHandicap << QString::number(handicap);
            qDebug() << "Female White: " << handicap;

        }
        else if(QString::compare(this->selectedPlayersTee[i], "Yellow", Qt::CaseInsensitive) == 0 &&
                QString::compare(this->selectedPlayersGender[i], "female", Qt::CaseInsensitive) == 0)
        {
            handicap = this->selectedPlayersHcp[i].toDouble() * (double)(fslope[0] / 113) + (double)(fcr[0] - par) + 0.5;
            selectedPlayersHandicap << QString::number(handicap);
            qDebug() << "Female Yellow: " << handicap;

        }
        else if(QString::compare(this->selectedPlayersTee[i], "Blue", Qt::CaseInsensitive) == 0 &&
                QString::compare(this->selectedPlayersGender[i], "female", Qt::CaseInsensitive) == 0)
        {
            handicap = this->selectedPlayersHcp[i].toDouble() * (double)(fslope[1] / 113) + (double)(fcr[1] - par) + 0.5;
            selectedPlayersHandicap << QString::number(handicap);
            qDebug() << "Female Blue: " << handicap;

        }
        else if(QString::compare(this->selectedPlayersTee[i], "Red", Qt::CaseInsensitive) == 0 &&
                QString::compare(this->selectedPlayersGender[i], "female", Qt::CaseInsensitive) == 0)
        {
            handicap = this->selectedPlayersHcp[i].toDouble() * (double)(fslope[2] / 113) + (double)(fcr[2] - par) + 0.5;
            selectedPlayersHandicap << QString::number(handicap);
            qDebug() << "Female Red: " << handicap;

        }


    }
}


