#include "newround.h"
#include "ui_newround.h"
#include "datahandling.h"
#include "xmlparser.h"
#include "basicscorecard.h"
#include <QMessageBox>

#include <QtDebug>


newround::newround(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::newround)
{
    ui->setupUi(this);

    ui->comboBox_player2->setHidden(true);
    ui->comboBox_player3->setHidden(true);
    ui->comboBox_player4->setHidden(true);

    ui->hcp_player2->setHidden(true);
    ui->hcp_player3->setHidden(true);
    ui->hcp_player4->setHidden(true);

    ui->tee_player2->setHidden(true);
    ui->tee_player3->setHidden(true);
    ui->tee_player4->setHidden(true);

    datahandling *playerAndCourseData = datahandling::instance();
    xmlparser *Parser = new xmlparser();

    playerAndCourseData->clearData();
    Parser->loadPlayerXMLFile();
    Parser->loadCourseXMLFile();

    const QList<player>& players = playerAndCourseData->getPlayers();
    const QList<course>& courses = playerAndCourseData->getCourses();

    QStringList player_namelist;

    foreach(player plr,players)
    {
        player_namelist.push_back(plr.m_name);
        hcps.push_back(plr.m_hcp);
    }

    foreach(course crs, courses)
    {
        courseNames.push_back(crs.m_name);
        courseFiles.push_back(crs.m_file);
    }

    ui->comboBox_player1->addItems(player_namelist);
    ui->comboBox_player2->addItems(player_namelist);
    ui->comboBox_player3->addItems(player_namelist);
    ui->comboBox_player4->addItems(player_namelist);
    ui->comboBox_course->addItems(courseNames);
}



void newround::on_checkBox_player1_toggled(bool checked)
{
    if(checked)
    {
        ui->comboBox_player1->setHidden(true);
        ui->hcp_player1->setHidden(true);
        ui->tee_player1->setHidden(true);
        ui->comboBox_player1->setHidden(false);
        ui->hcp_player1->setHidden(false);
        ui->tee_player1->setHidden(false);
    }
    if(!checked)
    {
        ui->comboBox_player1->setHidden(true);
        ui->hcp_player1->setHidden(true);
        ui->tee_player1->setHidden(true);
        ui->comboBox_player1->setHidden(true);
        ui->hcp_player1->setHidden(true);
        ui->tee_player1->setHidden(true);
    }
}

void newround::on_checkBox_player2_toggled(bool checked)
{
    if(checked)
    {
        ui->comboBox_player2->setEnabled(true);
        ui->hcp_player2->setEnabled(true);
        ui->tee_player2->setEnabled(true);
        ui->comboBox_player2->setHidden(false);
        ui->hcp_player2->setHidden(false);
        ui->tee_player2->setHidden(false);

    }
    if(!checked)
    {
        ui->comboBox_player2->setDisabled(true);
        ui->hcp_player2->setDisabled(true);
        ui->tee_player2->setDisabled(true);
        ui->comboBox_player2->setHidden(true);
        ui->hcp_player2->setHidden(true);
        ui->tee_player2->setHidden(true);

    }
}

void newround::on_checkBox_player3_toggled(bool checked)
{
    if(checked)
    {
        ui->comboBox_player3->setEnabled(true);
        ui->hcp_player3->setEnabled(true);
        ui->tee_player3->setEnabled(true);
        ui->comboBox_player3->setHidden(false);
        ui->hcp_player3->setHidden(false);
        ui->tee_player3->setHidden(false);

    }
    if(!checked)
    {
        ui->comboBox_player3->setDisabled(true);
        ui->hcp_player3->setDisabled(true);
        ui->tee_player3->setDisabled(true);
        ui->comboBox_player3->setHidden(true);
        ui->hcp_player3->setHidden(true);
        ui->tee_player3->setHidden(true);

    }
}

void newround::on_checkBox_player4_toggled(bool checked)
{
    if(checked)
    {
        ui->comboBox_player4->setEnabled(true);
        ui->hcp_player4->setEnabled(true);
        ui->tee_player4->setEnabled(true);
        ui->comboBox_player4->setHidden(false);
        ui->hcp_player4->setHidden(false);
        ui->tee_player4->setHidden(false);

    }
    if(!checked)
    {
        ui->comboBox_player4->setDisabled(true);
        ui->hcp_player4->setDisabled(true);
        ui->tee_player4->setDisabled(true);
        ui->comboBox_player4->setHidden(true);
        ui->hcp_player4->setHidden(true);
        ui->tee_player4->setHidden(true);

    }
}

void newround::on_comboBox_player1_currentIndexChanged(int index)
{
    for(int i = 0; i < hcps.length(); i++)
    {
        if(index == i)
            ui->hcp_player1->setPlainText(hcps[index]);
    }
}

void newround::on_comboBox_player2_currentIndexChanged(int index)
{
    for(int i = 0; i < hcps.length(); i++)
    {
        if(index == i)
            ui->hcp_player2->setPlainText(hcps[index]);
    }
}

void newround::on_comboBox_player3_currentIndexChanged(int index)
{
    for(int i = 0; i < hcps.length(); i++)
    {
        if(index == i)
            ui->hcp_player3->setPlainText(hcps[index]);
    }
}

void newround::on_comboBox_player4_currentIndexChanged(int index)
{
    for(int i = 0; i < hcps.length(); i++)
    {
        if(index == i)
            ui->hcp_player4->setPlainText(hcps[index]);
    }
}

void newround::on_pushButton_continue_clicked()
{
    datahandling *playerAndCourseData = datahandling::instance();
    xmlparser *Parser = new xmlparser();
    int courseIndex;

    courseIndex = ui->comboBox_course->currentIndex();
    playerAndCourseData->selectedCourse = courseFiles[courseIndex];

    Parser->parseSelectedCourse();
    saveSelectedPlayers();
    playerAndCourseData->calculateHandicaps();

    BasicScorecard *basicscorecard = new BasicScorecard();
    QMessageBox msgBox;
    msgBox.setText("Do you want to start a round?");
    msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
    int ret = msgBox.exec();
    switch (ret)
    {
      case QMessageBox::Yes:
        basicscorecard->show();
        this->hide();
          break;
      case QMessageBox::No:
          break;
    }
}

void newround::saveSelectedPlayers()
{
    datahandling *playerAndCourseData = datahandling::instance();
    const QList<player>& players = playerAndCourseData->getPlayers();
    QStringList gender;

    playerAndCourseData->selectedPlayers.clear();
    playerAndCourseData->selectedPlayersHcp.clear();
    playerAndCourseData->selectedPlayersTee.clear();
    playerAndCourseData->selectedPlayersGender.clear();

    foreach(player plr,players)
    {
        gender.push_back(plr.m_gender);
    }

    if(ui->checkBox_player1->isChecked())
    {
        playerAndCourseData->selectedPlayers << ui->comboBox_player1->currentText();
        playerAndCourseData->selectedPlayersHcp << ui->hcp_player1->toPlainText();
        playerAndCourseData->selectedPlayersTee << ui->tee_player1->currentText();
        playerAndCourseData->selectedPlayersGender << gender[ui->comboBox_player1->currentIndex()];
    }
    if(ui->checkBox_player2->isChecked())
    {
        playerAndCourseData->selectedPlayers << ui->comboBox_player2->currentText();
        playerAndCourseData->selectedPlayersHcp << ui->hcp_player2->toPlainText();
        playerAndCourseData->selectedPlayersTee << ui->tee_player2->currentText();
        playerAndCourseData->selectedPlayersGender << gender[ui->comboBox_player2->currentIndex()];

    }
    if(ui->checkBox_player3->isChecked())
    {
        playerAndCourseData->selectedPlayers << ui->comboBox_player3->currentText();
        playerAndCourseData->selectedPlayersHcp << ui->hcp_player3->toPlainText();
        playerAndCourseData->selectedPlayersTee << ui->tee_player3->currentText();
        playerAndCourseData->selectedPlayersGender << gender[ui->comboBox_player3->currentIndex()];

    }
    if(ui->checkBox_player4->isChecked())
    {
        playerAndCourseData->selectedPlayers << ui->comboBox_player4->currentText();
        playerAndCourseData->selectedPlayersHcp << ui->hcp_player4->toPlainText();
        playerAndCourseData->selectedPlayersTee << ui->tee_player4->currentText();
        playerAndCourseData->selectedPlayersGender << gender[ui->comboBox_player4->currentIndex()];

    }  
}

