#include "playermanagement.h"
#include "ui_playermanagement.h"
#include "pcmanagement.h"

#include <QFileDialog>
#include <QMessageBox>
#include <QDomNode>
#include <QCoreApplication>

#include <QDebug>

#define N900

playermanagement::playermanagement(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::playermanagement)
{
    ui->setupUi(this);
    fileName = (QCoreApplication::applicationDirPath() + "/xml/players/playerdata.xml");

    #ifdef N900
        fileName = "/opt/GolfScorecard/xml/players/playerdata.xml";
    #endif
}

playermanagement::~playermanagement()
{
    delete ui;
}

void playermanagement::changeEvent(QEvent *e)
{
    QMainWindow::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        ui->retranslateUi(this);
        break;
    default:
        break;
    }
}

void playermanagement::on_saveAndContinue_clicked()
{
    if(!ui->fullName->toPlainText().isEmpty() && !ui->hcp->toPlainText().isEmpty())
    {

        if (fileName.isEmpty()){
            QMessageBox::warning(this, tr("Player file"),
                                 tr("EMPTY! Cannot read file."));

        }

        QFile file(fileName);

        if (!file.open(QFile::ReadOnly | QFile::Text)) {
            QMessageBox::warning(this, tr("Player file"),
                                 tr("Cannot read file %1:\n%2.")
                                 .arg(fileName)
                                 .arg(file.errorString()));

        }

        QDomDocument doc("Players");

        if( !doc.setContent( &file ) )
        {
            file.close();
            QMessageBox::warning(this, tr("Parsing failed"), tr("Parsing failed totally"));
        }
        file.close();

        file.remove(fileName);

        QDomElement root = doc.documentElement();
        if( root.tagName() != "players" )
            QMessageBox::warning(this, tr("No root found!"), tr("There was no root in XML found!"));

        QDomElement tag = doc.createElement("player");
        tag.setAttribute("name", ui->fullName->toPlainText());
        tag.setAttribute("gender", ui->gender_comboBox->currentText());
        tag.setAttribute("hcp", ui->hcp->toPlainText());
        root.appendChild(tag);

        qDebug() << doc.toString();

        if (!file.open(QFile::WriteOnly | QFile::Text)) {
            QMessageBox::warning(this, tr("Player file"),
                                 tr("Cannot read file %1:\n%2.")
                                 .arg(fileName)
                                 .arg(file.errorString()));

        }

        QTextStream ts( &file );
        ts << doc.toString();

        file.close();

        QMessageBox msgBox;
        msgBox.setText("Player created!");
        msgBox.exec();

        PCManagement *pcm = new PCManagement();
        pcm->show();
        this->hide();
    }
    else
    {
        QMessageBox msgBox;
        msgBox.setText("You have not filled all fields!");
        msgBox.exec();
    }
}

void playermanagement::on_prevWindowButton_clicked()
{
    PCManagement *pcm = new PCManagement();
    pcm->show();
    this->hide();
}
