#include "xmlparser.h"
#include "datahandling.h"

#include <QFileDialog>
#include <QMessageBox>
#include <QDomNode>
#include <QCoreApplication>

#include <QDebug>

#define N900

xmlparser::xmlparser()
{
    fileName = (QCoreApplication::applicationDirPath() + "/xml/players/playerdata.xml");
    fileNameCourses = (QCoreApplication::applicationDirPath() + "/xml/courses/coursedata.xml");

    #ifdef N900
        fileName = "/opt/GolfScorecard/xml/players/playerdata.xml";
        fileNameCourses = "/opt/GolfScorecard/xml/courses/coursedata.xml";
    #endif
}

void xmlparser::loadPlayerXMLFile()
{
    datahandling *playerdata = datahandling::instance();

    if (fileName.isEmpty()){
        QMessageBox::warning(this, tr("Player file"),
                             tr("EMPTY! Cannot read file."));

    }

    QFile file(fileName);

    if (!file.open(QFile::ReadOnly | QFile::Text)) {
        QMessageBox::warning(this, tr("Player file"),
                             tr("Cannot read file %1:\n%2.")
                             .arg(fileName)
                             .arg(file.errorString()));

    }

    QDomDocument doc("Players");

    if( !doc.setContent( &file ) )
    {
      file.close();
      QMessageBox::warning(this, tr("Parsing failed"), tr("Parsing failed totally"));
    }
    file.close();

    QDomElement root = doc.documentElement();
    if( root.tagName() != "players" )
      QMessageBox::warning(this, tr("No root found!"), tr("There was no root in XML found!"));

    QDomElement child = root.firstChildElement("player");
    while (!child.isNull())
    {
        playerdata->addPlayer(child.attribute("name",""),child.attribute("hcp",""),child.attribute("gender", ""));
        child = child.nextSiblingElement("player");
    }
}

void xmlparser::loadCourseXMLFile()
{
    datahandling *coursedata = datahandling::instance();

    if (fileNameCourses.isEmpty()){
        QMessageBox::warning(this, tr("Course file"),
                             tr("EMPTY! Cannot read file."));

    }

    QFile file(fileNameCourses);

    if (!file.open(QFile::ReadOnly | QFile::Text)) {
        QMessageBox::warning(this, tr("Course file"),
                             tr("Cannot read file %1:\n%2.")
                             .arg(fileNameCourses)
                             .arg(file.errorString()));

    }

    QDomDocument doc("Courses");

    if( !doc.setContent( &file ) )
    {
      file.close();
      QMessageBox::warning(this, tr("Parsing failed"), tr("Parsing failed totally"));
    }
    file.close();

    QDomElement root = doc.documentElement();
    if( root.tagName() != "courses" )
      QMessageBox::warning(this, tr("No root found!"), tr("There was no root in XML found!"));

    QDomElement child = root.firstChildElement("course");
    while (!child.isNull())
    {
        coursedata->addCourses(child.attribute("name", ""), child.attribute("course_file", ""));
        child = child.nextSiblingElement("course");
    }
}

void xmlparser::parseSelectedCourse()
{
    datahandling *coursedata = datahandling::instance();
    QString selectedCourse = (QCoreApplication::applicationDirPath() + "/xml/courses/" + coursedata->selectedCourse);

    #ifdef N900
        selectedCourse = ("/opt/GolfScorecard/xml/courses/" + coursedata->selectedCourse);
    #endif

    if (selectedCourse.isEmpty()){
        QMessageBox::warning(this, tr("Course file"),
                             tr("EMPTY! Cannot read file."));

    }

    QFile file(selectedCourse);

    if (!file.open(QFile::ReadOnly | QFile::Text)) {
        QMessageBox::warning(this, tr("Course file"),
                             tr("Cannot read file %1:\n%2.")
                             .arg(selectedCourse)
                             .arg(file.errorString()));
    }

    QDomDocument doc("Courses");

    if( !doc.setContent( &file ) )
    {
      file.close();
      QMessageBox::warning(this, tr("Parsing failed"), tr("Parsing failed totally"));
    }
    file.close();

    QDomElement root = doc.documentElement();
    if( root.tagName() != "courses" )
      QMessageBox::warning(this, tr("No root found!"), tr("There was no root in XML found!"));

    QDomElement course = root.firstChildElement("course");
    QDomElement cr = course.firstChildElement("cr");
    QDomElement male = cr.firstChildElement("male");
    QDomElement female = cr.firstChildElement("female");
    QDomElement slope = course.firstChildElement("slope");
    QDomElement hole = course.firstChildElement("hole");

    QDomElement white = hole.firstChildElement("white");
    QDomElement yellow = hole.firstChildElement("yellow");
    QDomElement blue = hole.firstChildElement("blue");
    QDomElement red = hole.firstChildElement("red");
    QDomElement green = hole.firstChildElement("green");



    while (!course.isNull())
    {
        coursedata->addCourseData(course.attribute("name", ""), course.attribute("par", ""),
                                  course.attribute("latitude", "").toDouble(), course.attribute("longitude", "").toDouble(),
                                  course.attribute("country", ""), course.attribute("city", ""));
        while (!cr.isNull())
        {
            while (!male.isNull())
            {
                coursedata->addCourseCrMale(male.attribute("white", "").toDouble(), male.attribute("yellow", "").toDouble(),
                                            male.attribute("blue", "").toDouble(), male.attribute("red", "").toDouble());
                male = male.nextSiblingElement("male");
            }

            while (!female.isNull())
            {
                coursedata->addCourseCrFemale(female.attribute("yellow", "").toDouble(),
                                            female.attribute("blue", "").toDouble(), female.attribute("red", "").toDouble());
                female = female.nextSiblingElement("female");
            }
            cr = cr.nextSiblingElement("cr");
        }

        male = slope.firstChildElement("male");
        female = slope.firstChildElement("female");

        while (!slope.isNull())
        {
            while (!male.isNull())
            {
                coursedata->addCourseSlopeMale(male.attribute("white", "").toDouble(), male.attribute("yellow", "").toDouble(),
                                            male.attribute("blue", "").toDouble(), male.attribute("red", "").toDouble());
                male = male.nextSiblingElement("male");
            }

            while (!female.isNull())
            {
                coursedata->addCourseSlopeFemale(female.attribute("yellow", "").toDouble(),
                                            female.attribute("blue", "").toDouble(), female.attribute("red", "").toDouble());
                female = female.nextSiblingElement("female");
            }
            slope = slope.nextSiblingElement("slope");
        }

        while (!hole.isNull())
        {
            coursedata->addHoleData(hole.attribute("id", ""), hole.attribute("hcp", ""),
                                    hole.attribute("par", ""), hole.attribute("map_uri", ""));
            while (!white.isNull())
            {
                coursedata->addWhiteTee(white.attribute("length", ""),
                                        white.attribute("latitude", "").toDouble(), white.attribute("longitude", "").toDouble());
                white = white.nextSiblingElement("white");
            }
            while (!yellow.isNull())
            {
                coursedata->addYellowTee(yellow.attribute("length", ""),
                                        yellow.attribute("latitude", "").toDouble(), yellow.attribute("longitude", "").toDouble());
                yellow = yellow.nextSiblingElement("yellow");
            }
            while (!blue.isNull())
            {
                coursedata->addBlueTee(blue.attribute("length", ""),
                                        blue.attribute("latitude", "").toDouble(), blue.attribute("longitude", "").toDouble());
                blue = blue.nextSiblingElement("blue");
            }
            while (!red.isNull())
            {
                coursedata->addRedTee(red.attribute("length", ""),
                                        red.attribute("latitude", "").toDouble(), red.attribute("longitude", "").toDouble());
                red = red.nextSiblingElement("red");
            }
            while (!green.isNull())
            {
                coursedata->addGreenInfo(green.attribute("latitude", "").toDouble(), green.attribute("longitude", "").toDouble());
                green = green.nextSiblingElement("green");
            }

            hole = hole.nextSiblingElement("hole");
            white = hole.firstChildElement("white");
            yellow = hole.firstChildElement("yellow");
            blue = hole.firstChildElement("blue");
            red = hole.firstChildElement("red");
            green = hole.firstChildElement("green");
        }
        course = course.nextSiblingElement("course");
    }
}
